@@ -12,7 +12,7 @@ use crate::{
   messages::submessages::submessage::AckSubmessage,
   network::{
     constant::{user_traffic_multicast_port, user_traffic_unicast_port},
-    util::{get_local_multicast_locators, get_local_unicast_socket_address},
+    util::{get_local_multicast_locators, get_local_unicast_locators},
   },
   structure::{
     guid::{EntityId, EntityKind, GUID},
@@ -84,7 +84,7 @@ impl RtpsReaderProxy {
     participant_id: u16,
   ) -> RtpsReaderProxy {
     let unicast_locator_list =
-      get_local_unicast_socket_address(user_traffic_unicast_port(domain_id, participant_id));
+      get_local_unicast_locators(user_traffic_unicast_port(domain_id, participant_id));
 
     let multicast_locator_list =
       get_local_multicast_locators(user_traffic_multicast_port(domain_id));
