@@ -1,14 +1,17 @@
-/// DeserializerAdapter is used to fit serde Deserializer implementations and DataReader together.
-/// DataReader cannot assume a specific serialization format, so it needs to be given as a parameter.
+/// DeserializerAdapter is used to fit serde Deserializer implementations and
+/// DataReader together. DataReader cannot assume a specific serialization
+/// format, so it needs to be given as a parameter.
 ///
-/// for WITH_KEY topics, we need to be able to (de)serailize the key in addition to data.
+/// for WITH_KEY topics, we need to be able to (de)serailize the key in addition
+/// to data.
 pub mod no_key {
-  use serde::de::DeserializeOwned;
-  use serde::ser::Serialize;
+  use serde::{de::DeserializeOwned, ser::Serialize};
   use bytes::Bytes;
 
-  use crate::serialization::error::Result;
-  use crate::messages::submessages::submessage_elements::serialized_payload::RepresentationIdentifier;
+  use crate::{
+    messages::submessages::submessage_elements::serialized_payload::RepresentationIdentifier,
+    serialization::error::Result,
+  };
 
   pub trait DeserializerAdapter<D>
   where
@@ -20,8 +23,8 @@ pub mod no_key {
 
     fn from_bytes(input_bytes: &[u8], encoding: RepresentationIdentifier) -> Result<D>;
 
-    /// This method has a default implementation, but the default will make a copy of
-    /// all the input data in memory and then call from_bytes() .
+    /// This method has a default implementation, but the default will make a
+    /// copy of all the input data in memory and then call from_bytes() .
     // In order to avoid the copy, implement also this method.
     fn from_vec_bytes(input_vec_bytes: &[Bytes], encoding: RepresentationIdentifier) -> Result<D> {
       let total_len = input_vec_bytes.iter().map(|s| s.len()).sum();
@@ -45,15 +48,14 @@ pub mod no_key {
 }
 
 pub mod with_key {
-  use serde::Serialize;
-  use serde::de::DeserializeOwned;
-
+  use serde::{de::DeserializeOwned, Serialize};
   use bytes::Bytes;
 
-  use crate::serialization::error::Result;
-  use crate::dds::traits::key::*;
-  use crate::messages::submessages::submessage_elements::serialized_payload::RepresentationIdentifier;
-
+  use crate::{
+    dds::traits::key::*,
+    messages::submessages::submessage_elements::serialized_payload::RepresentationIdentifier,
+    serialization::error::Result,
+  };
   use super::no_key;
 
   pub trait DeserializerAdapter<D>: no_key::DeserializerAdapter<D>
