@@ -5,8 +5,8 @@ pub struct TypeDesc {
 } // placeholders
 
 impl TypeDesc {
-  pub fn new(my_name: &str) -> TypeDesc {
-    TypeDesc { my_name: my_name.to_string() }
+  pub fn new(my_name: String) -> TypeDesc {
+    TypeDesc { my_name }
   }
   pub fn name(&self) -> &str {
     &self.my_name
