@@ -1,19 +1,20 @@
-use crate::{dds::traits::key::*};
+use crate::dds::{sampleinfo::*, traits::key::*};
 
-use crate::dds::sampleinfo::*;
-
-//use super::{interfaces::{IDataSample, IDataSampleConvert, IKeyedDataSample, IKeyedDataSampleConvert}, no_key::wrappers::NoKeyWrapper};
+//use super::{interfaces::{IDataSample, IDataSampleConvert, IKeyedDataSample,
+// IKeyedDataSampleConvert}, no_key::wrappers::NoKeyWrapper};
 
 /// DDS spec 2.2.2.5.4
 ///
-/// Note that no_key::DataSample and with_key::DataSample are two different but similar structs.
+/// Note that no_key::DataSample and with_key::DataSample are two different but
+/// similar structs.
 ///
 /// We are making a bit unorthodox use of `Result`:
-/// It replaces the use of valid_data flag, because when valid_data = false, we should
-/// not provide any data value.
+/// It replaces the use of valid_data flag, because when valid_data = false, we
+/// should not provide any data value.
 /// Now
 /// * `Ok(D)` means valid_data = true and there is a sample.
-/// * `Err(D::K)` means valid_data = false, no sample exists, but only a Key and instance_state has changed.
+/// * `Err(D::K)` means valid_data = false, no sample exists, but only a Key and
+///   instance_state has changed.
 
 #[derive(PartialEq, Debug)]
 pub struct DataSample<D: Keyed> {
@@ -30,13 +31,14 @@ where
     DataSample { sample_info, value }
   }
 
-  // convenience shorthand to get the key directly, without digging out the "value"
-  pub fn get_key(&self) -> D::K
+  // convenience shorthand to get the key directly, without digging out the
+  // "value"
+  pub fn key(&self) -> D::K
   where
     <D as Keyed>::K: Key,
   {
     match &self.value {
-      Ok(d) => d.get_key(),
+      Ok(d) => d.key(),
       Err(k) => k.clone(),
     }
   } // fn
