@@ -4,53 +4,47 @@ use std::{
   time::Duration,
 };
 
-use mio::{Poll, Events, Token, Ready, PollOpt, Evented};
-use mio_extras::channel::{self as mio_channel, Receiver, SendError,};
-
+use mio::{Evented, Events, Poll, PollOpt, Ready, Token};
+use mio_extras::channel::{self as mio_channel, Receiver, SendError};
 use serde::Serialize;
-
 #[allow(unused_imports)]
-use log::{error,warn,debug,trace,info};
+use log::{debug, error, info, trace, warn};
 
 use crate::{
-  discovery::discovery::DiscoveryCommand, serialization::CDRSerializerAdapter,
-  dds::qos::policy::Liveliness, structure::time::Timestamp,
+  dds::{
+    ddsdata::DDSData,
+    helpers::*,
+    pubsub::Publisher,
+    qos::{
+      policy::{Liveliness, Reliability},
+      HasQoSPolicy, QosPolicies,
+    },
+    statusevents::*,
+    topic::Topic,
+    traits::{
+      dds_entity::DDSEntity, key::*, serde_adapters::with_key::SerializerAdapter, TopicDescription,
+    },
+    values::result::{Error, Result},
+  },
+  discovery::{data_types::topic_data::SubscriptionBuiltinTopicData, discovery::DiscoveryCommand},
+  log_and_err_internal, log_and_err_precondition_not_met,
+  serialization::CDRSerializerAdapter,
+  structure::{
+    cache_change::ChangeKind,
+    dds_cache::DDSCache,
+    entity::RTPSEntity,
+    guid::{EntityId, GUID},
+    time::Timestamp,
+    topic_kind::TopicKind,
+  },
 };
-use crate::structure::entity::{RTPSEntity};
-use crate::structure::{
-  dds_cache::DDSCache,
-  guid::{GUID, EntityId},
-  topic_kind::TopicKind,
-  cache_change::ChangeKind,
-};
-
-use crate::dds::pubsub::Publisher;
-use crate::dds::topic::Topic;
-use crate::log_and_err_precondition_not_met;
-use crate::log_and_err_internal;
-
-use crate::dds::values::result::{ Result, Error, };
-use crate::dds::statusevents::*;
-use crate::dds::traits::dds_entity::DDSEntity;
-use crate::dds::traits::key::*;
-use crate::dds::traits::TopicDescription;
-use crate::dds::helpers::*;
-
-use crate::dds::qos::{
-  HasQoSPolicy, QosPolicies,
-  policy::{Reliability},
-};
-use crate::dds::traits::serde_adapters::with_key::SerializerAdapter;
-//use crate::dds::traits::serde_adapters::no_key::SerializerAdapter 
+//use crate::dds::traits::serde_adapters::no_key::SerializerAdapter
 //  as no_key_SerializerAdapter; // needs to be visible only, no direct use
- 
 use crate::messages::submessages::submessage_elements::serialized_payload::SerializedPayload;
-
-use crate::{discovery::data_types::topic_data::SubscriptionBuiltinTopicData, dds::ddsdata::DDSData};
-use super::super::{datasample_cache::DataSampleCache, writer::WriterCommand, };
+use super::super::{datasample_cache::DataSampleCache, writer::WriterCommand};
 
 /// Simplified type for CDR encoding
-pub type DataWriterCdr<D> = DataWriter<D,CDRSerializerAdapter<D>>;
+pub type DataWriterCdr<D> = DataWriter<D, CDRSerializerAdapter<D>>;
 
 /// DDS DataWriter for keyed topics
 ///
@@ -74,7 +68,7 @@ pub type DataWriterCdr<D> = DataWriter<D,CDRSerializerAdapter<D>>;
 /// impl Keyed for SomeType {
 ///   type K = i32;
 ///
-///   fn get_key(&self) -> Self::K {
+///   fn key(&self) -> Self::K {
 ///     self.a
 ///   }
 /// }
@@ -83,8 +77,7 @@ pub type DataWriterCdr<D> = DataWriter<D,CDRSerializerAdapter<D>>;
 /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
 /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None);
 /// ```
-pub struct DataWriter<D: Keyed + Serialize, SA: SerializerAdapter<D> = CDRSerializerAdapter<D>>
-{
+pub struct DataWriter<D: Keyed + Serialize, SA: SerializerAdapter<D> = CDRSerializerAdapter<D>> {
   my_publisher: Publisher,
   my_topic: Topic,
   qos_policy: QosPolicies,
@@ -105,17 +98,19 @@ where
   fn drop(&mut self) {
     match self
       .discovery_command
-      .send(DiscoveryCommand::RemoveLocalWriter {
-        guid: self.get_guid(),
-      }) {
+      .send(DiscoveryCommand::RemoveLocalWriter { guid: self.guid() })
+    {
       Ok(_) => {}
 
       // This is fairly normal at shutdown, as the other end is down already.
-      Err(SendError::Disconnected(_cmd)) => debug!(
-        "Failed to send REMOVE_LOCAL_WRITER DiscoveryCommand: Disconnected." ),
+      Err(SendError::Disconnected(_cmd)) => {
+        debug!("Failed to send REMOVE_LOCAL_WRITER DiscoveryCommand: Disconnected.")
+      }
       // other errors must be taken more seriously
-      Err(e) => 
-        error!("Failed to send REMOVE_LOCAL_WRITER DiscoveryCommand. {:?}",e ),
+      Err(e) => error!(
+        "Failed to send REMOVE_LOCAL_WRITER DiscoveryCommand. {:?}",
+        e
+      ),
     }
   }
 }
@@ -137,39 +132,40 @@ where
   ) -> Result<DataWriter<D, SA>> {
     let entity_id = match guid {
       Some(g) => g.entity_id,
-      None => EntityId::ENTITYID_UNKNOWN,
+      None => EntityId::UNKNOWN,
     };
 
-    let dp = match publisher.get_participant() {
+    let dp = match publisher.participant() {
       Some(dp) => dp,
-      None => return 
-        log_and_err_precondition_not_met!("Cannot create new DataWriter, DomainParticipant doesn't exist.") ,
+      None => {
+        return log_and_err_precondition_not_met!(
+          "Cannot create new DataWriter, DomainParticipant doesn't exist."
+        )
+      }
     };
 
-    let my_guid = GUID::new_with_prefix_and_id(dp.get_guid_prefix(), entity_id );
+    let my_guid = GUID::new_with_prefix_and_id(dp.guid_prefix(), entity_id);
 
     match dds_cache.write() {
-      Ok(mut cache) => cache.add_new_topic(
-        topic.get_name(),
-        TopicKind::NoKey,
-        topic.get_type(),
-      ),
+      Ok(mut cache) => cache.add_new_topic(topic.name(), TopicKind::NoKey, topic.get_type()),
       Err(e) => panic!("DDSCache is poisoned. {:?}", e),
     };
 
-    if let Some(lv) = topic.get_qos().liveliness { match lv {
-      Liveliness::Automatic { lease_duration: _ } => (),
-      Liveliness::ManualByParticipant { lease_duration: _ } => {
-        match discovery_command.send(DiscoveryCommand::ManualAssertLiveliness) {
-          Ok(_) => (),
-          Err(e) => {
-            error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
+    if let Some(lv) = topic.qos().liveliness {
+      match lv {
+        Liveliness::Automatic { lease_duration: _ } => (),
+        Liveliness::ManualByParticipant { lease_duration: _ } => {
+          match discovery_command.send(DiscoveryCommand::ManualAssertLiveliness) {
+            Ok(_) => (),
+            Err(e) => {
+              error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
+            }
           }
         }
+        Liveliness::ManualByTopic { lease_duration: _ } => (),
       }
-      Liveliness::ManualByTopic { lease_duration: _ } => (),
-    } };
-    let qos = topic.get_qos();
+    };
+    let qos = topic.qos();
     Ok(DataWriter {
       my_publisher: publisher,
       my_topic: topic,
@@ -184,9 +180,10 @@ where
     })
   }
 
-  // This one function provides both get_matched_subscrptions and get_matched_subscription_data
-  // TODO: Maybe we could return references to the subscription data to avoid copying?
-  // But then what if the result set changes while the application processes it?
+  // This one function provides both get_matched_subscrptions and
+  // get_matched_subscription_data TODO: Maybe we could return references to the
+  // subscription data to avoid copying? But then what if the result set changes
+  // while the application processes it?
 
   /// Manually refreshes liveliness if QoS allows it
   ///
@@ -210,7 +207,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -224,21 +221,23 @@ where
 
   // TODO: What is this function? To what part of DDS spec does it correspond to?
   pub fn refresh_manual_liveliness(&self) {
-    if let Some(lv) = self.get_qos().liveliness { match lv {
-      Liveliness::Automatic { lease_duration: _ } => (),
-      Liveliness::ManualByParticipant { lease_duration: _ } => {
-        match self
-          .discovery_command
-          .send(DiscoveryCommand::ManualAssertLiveliness)
-        {
-          Ok(_) => (),
-          Err(e) => {
-            error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
+    if let Some(lv) = self.qos().liveliness {
+      match lv {
+        Liveliness::Automatic { lease_duration: _ } => (),
+        Liveliness::ManualByParticipant { lease_duration: _ } => {
+          match self
+            .discovery_command
+            .send(DiscoveryCommand::ManualAssertLiveliness)
+          {
+            Ok(_) => (),
+            Err(e) => {
+              error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
+            }
           }
         }
+        Liveliness::ManualByTopic { lease_duration: _ } => (),
       }
-      Liveliness::ManualByTopic { lease_duration: _ } => (),
-    } };
+    };
   }
 
   /// Writes single data instance to a topic.
@@ -263,7 +262,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -276,46 +275,53 @@ where
   /// data_writer.write(some_data, None).unwrap();
   /// ```
   pub fn write(&self, data: D, source_timestamp: Option<Timestamp>) -> Result<()> {
+    let send_buffer = SA::to_bytes(&data)?; // serialize
 
-    let send_buffer = SA::to_bytes( &data )?; // serialize
+    let ddsdata = DDSData::new(SerializedPayload::new_from_bytes(
+      SA::output_encoding(),
+      send_buffer,
+    ));
+    let writer_command = WriterCommand::DDSData {
+      data: ddsdata,
+      source_timestamp,
+    };
 
-    let ddsdata = DDSData::new( SerializedPayload::new_from_bytes( SA::output_encoding() , send_buffer) );
-    let writer_command = WriterCommand::DDSData { data: ddsdata , source_timestamp };
+    let timeout = match self.qos().reliability() {
+      Some(Reliability::Reliable { max_blocking_time }) => Some(max_blocking_time),
+      _ => None,
+    };
 
-    let timeout =
-      match self.get_qos().reliability() {
-        Some(Reliability::Reliable { max_blocking_time }) => Some(max_blocking_time),
-        _ => None,
-      };
-
-    match try_send_timeout(&self.cc_upload, writer_command, timeout)
-    {
+    match try_send_timeout(&self.cc_upload, writer_command, timeout) {
       Ok(_) => {
         self.refresh_manual_liveliness();
         Ok(())
       }
       Err(e) => {
-        warn!("Failed to write new data: topic={:?}  reason={:?}  timeout={:?}", 
-             self.my_topic.get_name(), e, timeout, );
+        warn!(
+          "Failed to write new data: topic={:?}  reason={:?}  timeout={:?}",
+          self.my_topic.name(),
+          e,
+          timeout,
+        );
         Err(Error::OutOfResources)
       }
     }
   }
 
-  /// This operation blocks the calling thread until either all data written by the 
-  /// reliable DataWriter entities is acknowledged by all
-  /// matched reliable DataReader entities, or else the duration specified by the 
-  /// `max_wait` parameter elapses, whichever happens first.
+  /// This operation blocks the calling thread until either all data written by
+  /// the reliable DataWriter entities is acknowledged by all
+  /// matched reliable DataReader entities, or else the duration specified by
+  /// the `max_wait` parameter elapses, whichever happens first.
   ///
   /// See DDS Spec 1.4 Section 2.2.2.4.1.12 wait_for_acknowledgments.
   ///
-  /// If this DataWriter is not set to Realiable, or there are no matched DataReaders
-  /// with Realibale QoS, the call succeeds imediately.
+  /// If this DataWriter is not set to Realiable, or there are no matched
+  /// DataReaders with Realibale QoS, the call succeeds imediately.
   ///
   /// Return values
-  /// * `Ok(true)` - all acknowledged 
+  /// * `Ok(true)` - all acknowledged
   /// * `Ok(false)`- timed out waiting for acknowledgments
-  /// * `Err(_)` - something went wrong 
+  /// * `Err(_)` - something went wrong
   ///
   /// # Examples
   ///
@@ -337,7 +343,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -355,17 +361,25 @@ where
       None => Ok(true),
       Some(Reliability::BestEffort) => Ok(true),
       Some(Reliability::Reliable { .. }) => {
-        let (acked_sender,acked_receiver) = mio_channel::sync_channel::<()>(1);
+        let (acked_sender, acked_receiver) = mio_channel::sync_channel::<()>(1);
         let poll = Poll::new()?;
-        poll.register(&acked_receiver, Token(0), Ready::readable(), PollOpt::edge() )?;
-        self.cc_upload.try_send(
-          WriterCommand::WaitForAcknowledgments { all_acked: acked_sender })?;
+        poll.register(
+          &acked_receiver,
+          Token(0),
+          Ready::readable(),
+          PollOpt::edge(),
+        )?;
+        self
+          .cc_upload
+          .try_send(WriterCommand::WaitForAcknowledgments {
+            all_acked: acked_sender,
+          })?;
         let mut events = Events::with_capacity(1);
-        poll.poll(&mut events, Some(max_wait) )?;
-        if let Some( _event ) = events.iter().next() {
-          let _ = acked_receiver.try_recv()
-            .or_else(|_e| log_and_err_internal!(
-              "wait_for_acknowledgments - Spurious poll event?"));
+        poll.poll(&mut events, Some(max_wait))?;
+        if let Some(_event) = events.iter().next() {
+          let _ = acked_receiver
+            .try_recv()
+            .or_else(|_e| log_and_err_internal!("wait_for_acknowledgments - Spurious poll event?"));
           // got reply
           Ok(true)
         } else {
@@ -398,7 +412,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -417,7 +431,7 @@ where
     match self
       .cc_upload
       .try_send(WriterCommand::ResetOfferedDeadlineMissedStatus {
-        writer_guid: self.get_guid(),
+        writer_guid: self.guid(),
       }) {
       Ok(_) => (),
       Err(e) => error!("Unable to send ResetOfferedDeadlineMissedStatus. {:?}", e),
@@ -448,7 +462,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -489,7 +503,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -517,7 +531,7 @@ where
     match self
       .cc_upload
       .try_send(WriterCommand::ResetOfferedDeadlineMissedStatus {
-        writer_guid: self.get_guid(),
+        writer_guid: self.guid(),
       }) {
       Ok(_) => (),
       Err(e) => error!("Unable to send ResetOfferedDeadlineMissedStatus. {:?}", e),
@@ -549,7 +563,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -591,7 +605,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -609,7 +623,7 @@ where
   pub fn get_publication_matched_status(&self) -> Result<PublicationMatchedStatus> {
     todo!()
   }
-  
+
   */
 
   /// Topic assigned to this DataWriter
@@ -634,7 +648,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -643,9 +657,9 @@ where
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic.clone(), None).unwrap();
   ///
-  /// assert_eq!(data_writer.get_topic(), &topic);
+  /// assert_eq!(data_writer.topic(), &topic);
   /// ```
-  pub fn get_topic(&self) -> &Topic {
+  pub fn topic(&self) -> &Topic {
     &self.my_topic
   }
 
@@ -671,7 +685,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -680,8 +694,8 @@ where
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
-  /// assert_eq!(data_writer.get_publisher(), &publisher);
-  pub fn get_publisher(&self) -> &Publisher {
+  /// assert_eq!(data_writer.publisher(), &publisher);
+  pub fn publisher(&self) -> &Publisher {
     &self.my_publisher
   }
 
@@ -707,7 +721,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -719,20 +733,22 @@ where
   /// data_writer.assert_liveliness().unwrap();
   /// ```
 
-  // TODO: This cannot really fail, so could change type to () (alternatively, make send error visible)
-  // TODO: Better make send failure visible, so application can see if Discovery has failed.
+  // TODO: This cannot really fail, so could change type to () (alternatively,
+  // make send error visible) TODO: Better make send failure visible, so
+  // application can see if Discovery has failed.
   pub fn assert_liveliness(&self) -> Result<()> {
     self.refresh_manual_liveliness();
 
-    match self.get_qos().liveliness {
+    match self.qos().liveliness {
       Some(Liveliness::ManualByTopic { lease_duration: _ }) => {
-        self.discovery_command
+        self
+          .discovery_command
           .send(DiscoveryCommand::AssertTopicLiveliness {
-            writer_guid: self.get_guid(),
+            writer_guid: self.guid(),
             manual_assertion: true, // by definition of this function
-            })
-          .unwrap_or_else( |e| error!("assert_liveness - Failed to send DiscoveryCommand. {:?}", e))
-        }
+          })
+          .unwrap_or_else(|e| error!("assert_liveness - Failed to send DiscoveryCommand. {:?}", e))
+      }
       _other => (),
     }
     Ok(())
@@ -761,14 +777,16 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(),
+  /// "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType,
+  /// CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// for sub in data_writer.get_matched_subscriptions().iter() {
   ///   // do something
@@ -782,7 +800,8 @@ where
   /// # Arguments
   ///
   /// * `key` - Key of the instance
-  /// * `source_timestamp` - DDS source timestamp (None uses now as time as specified in DDS spec)
+  /// * `source_timestamp` - DDS source timestamp (None uses now as time as
+  ///   specified in DDS spec)
   ///
   /// # Examples
   ///
@@ -804,7 +823,7 @@ where
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -828,24 +847,26 @@ where
   /// data_writer.dispose(1, None).unwrap();
   /// ```
   pub fn dispose(&self, key: <D as Keyed>::K, source_timestamp: Option<Timestamp>) -> Result<()> {
+    let send_buffer = SA::key_to_bytes(&key)?; // serialize key
 
-    let send_buffer = SA::key_to_bytes( &key  )?; // serialize key
-
-    let ddsdata = DDSData::new_disposed_by_key( 
+    let ddsdata = DDSData::new_disposed_by_key(
       ChangeKind::NotAliveDisposed,
-      SerializedPayload::new_from_bytes( SA::output_encoding() , send_buffer) 
+      SerializedPayload::new_from_bytes(SA::output_encoding(), send_buffer),
     );
-    self.cc_upload
-      .send(WriterCommand::DDSData { data: ddsdata , source_timestamp })
-      .or_else(|huh| 
-        log_and_err_internal!("Cannot send dispose command: {:?}", huh))?;
+    self
+      .cc_upload
+      .send(WriterCommand::DDSData {
+        data: ddsdata,
+        source_timestamp,
+      })
+      .or_else(|huh| log_and_err_internal!("Cannot send dispose command: {:?}", huh))?;
 
     self.refresh_manual_liveliness();
     Ok(())
   }
 }
 
-impl <D,SA> StatusEvented<DataWriterStatus> for DataWriter<D,SA>
+impl<D, SA> StatusEvented<DataWriterStatus> for DataWriter<D, SA>
 where
   D: Keyed + Serialize,
   SA: SerializerAdapter<D>,
@@ -856,7 +877,7 @@ where
 
   fn try_recv_status(&self) -> Option<DataWriterStatus> {
     self.status_receiver.try_recv_status()
-  }  
+  }
 }
 
 impl<D, SA> RTPSEntity for DataWriter<D, SA>
@@ -864,7 +885,7 @@ where
   D: Keyed + Serialize,
   SA: SerializerAdapter<D>,
 {
-  fn get_guid(&self) -> GUID {
+  fn guid(&self) -> GUID {
     self.my_guid
   }
 }
@@ -880,7 +901,7 @@ where
   //   Ok(())
   // }
 
-  fn get_qos(&self) -> QosPolicies {
+  fn qos(&self) -> QosPolicies {
     self.qos_policy.clone()
   }
 }
@@ -894,15 +915,18 @@ where
 
 #[cfg(test)]
 mod tests {
-  use super::*;
-  use crate::dds::participant::DomainParticipant;
-  use crate::test::random_data::*;
   use std::thread;
-  use crate::dds::traits::key::Keyed;
-  use crate::serialization::cdr_serializer::CDRSerializerAdapter;
+
   use byteorder::LittleEndian;
   use log::info;
 
+  use super::*;
+  use crate::{
+    dds::{participant::DomainParticipant, traits::key::Keyed},
+    serialization::cdr_serializer::CDRSerializerAdapter,
+    test::random_data::*,
+  };
+
   #[test]
   fn dw_write_test() {
     let domain_participant = DomainParticipant::new(0).expect("Publisher creation failed!");
@@ -912,7 +936,12 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii".to_string(), "Huh?".to_string(), &qos, TopicKind::WithKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "Huh?".to_string(),
+        &qos,
+        TopicKind::WithKey,
+      )
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -947,7 +976,12 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii".to_string(), "Huh?".to_string(), &qos, TopicKind::WithKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "Huh?".to_string(),
+        &qos,
+        TopicKind::WithKey,
+      )
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -960,7 +994,7 @@ mod tests {
       b: "Fobar".to_string(),
     };
 
-    let key = &data.get_key().hash_key();
+    let key = &data.key().hash_key();
     info!("key: {:?}", key);
 
     data_writer
@@ -969,7 +1003,7 @@ mod tests {
 
     thread::sleep(Duration::from_millis(100));
     data_writer
-      .dispose(data.get_key(), None)
+      .dispose(data.key(), None)
       .expect("Unable to dispose data");
 
     // TODO: verify that dispose is sent correctly
@@ -983,7 +1017,12 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii".to_string(), "Huh?".to_string(), &qos, TopicKind::WithKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "Huh?".to_string(),
+        &qos,
+        TopicKind::WithKey,
+      )
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -1002,6 +1041,6 @@ mod tests {
       .wait_for_acknowledgments(Duration::from_secs(2))
       .unwrap();
     assert!(res) // we should get "true" immediately, because we have
-                           // no Reliable QoS
+                 // no Reliable QoS
   }
 }
