@@ -14,7 +14,6 @@ use crate::{
       },
       HasQoSPolicy, QosPolicies,
     },
-    reader::Reader,
     rtps_reader_proxy::RtpsReaderProxy,
     rtps_writer_proxy::RtpsWriterProxy,
     topic::Topic,
@@ -26,17 +25,19 @@ use crate::{
     with_key::datawriter::DataWriter,
   },
   discovery::content_filter_property::ContentFilterProperty,
-  network::{constant::user_traffic_unicast_port, util::get_local_unicast_socket_address},
+  network::{constant::user_traffic_unicast_port, util::get_local_unicast_locators},
   serialization::{
     builtin_data_deserializer::BuiltinDataDeserializer,
     builtin_data_serializer::BuiltinDataSerializer,
   },
   structure::{
     entity::RTPSEntity,
-    guid::{EntityKind, GuidPrefix, GUID},
+    guid::{GuidPrefix, GUID},
     locator::Locator,
   },
 };
+#[cfg(test)]
+use crate::structure::guid::EntityKind;
 
 // Topic data contains all topic related
 // (including reader and writer data structures for serialization and
@@ -52,12 +53,16 @@ pub struct ReaderProxy {
 }
 
 impl ReaderProxy {
-  pub fn new(guid: GUID) -> ReaderProxy {
+  pub fn new(
+    guid: GUID,
+    unicast_locator_list: Vec<Locator>,
+    multicast_locator_list: Vec<Locator>,
+  ) -> ReaderProxy {
     ReaderProxy {
       remote_reader_guid: guid,
       expects_inline_qos: false,
-      unicast_locator_list: Vec::new(),
-      multicast_locator_list: Vec::new(),
+      unicast_locator_list,
+      multicast_locator_list,
     }
   }
 }
@@ -306,6 +311,7 @@ pub struct DiscoveredReaderData {
 }
 
 impl DiscoveredReaderData {
+  /*
   pub(crate) fn new(
     reader: &Reader,
     dp: &DomainParticipant,
@@ -325,11 +331,13 @@ impl DiscoveredReaderData {
       subscription_topic_data,
       content_filter: None,
     }
-  }
+  }*/
 
+  // This is for generating test data only
+  #[cfg(test)]
   pub fn default(topic_name: String, type_name: String) -> DiscoveredReaderData {
     let rguid = GUID::dummy_test_guid(EntityKind::READER_WITH_KEY_BUILT_IN);
-    let reader_proxy = ReaderProxy::new(rguid);
+    let reader_proxy = ReaderProxy::new(rguid, vec![], vec![]);
     let subscription_topic_data = SubscriptionBuiltinTopicData::new(
       rguid,
       topic_name,
@@ -614,7 +622,7 @@ impl DiscoveredWriterData {
     dp: &DomainParticipant,
   ) -> DiscoveredWriterData {
     let unicast_port = user_traffic_unicast_port(dp.domain_id(), dp.participant_id());
-    let unicast_addresses = get_local_unicast_socket_address(unicast_port);
+    let unicast_addresses = get_local_unicast_locators(unicast_port);
 
     let writer_proxy = WriterProxy::new(writer.guid(), vec![], unicast_addresses);
     let mut publication_topic_data = PublicationBuiltinTopicData::new(
