@@ -6,19 +6,19 @@
 //! DDS communicates over the network using the [RTPS](https://www.omg.org/spec/DDSI-RTPS/2.3)
 //! protocol, which by default runs over UDP/IP.
 //!
-//! This implementation does not attempt to make an accurate implementation of the DDS object API,
-//! as it would be quite unnatural to use in Rust as such. However, we aim for functional compatibility,
-//! while at the same time using Rust techniques and conventions.
+//! This implementation does not attempt to make an accurate implementation of
+//! the DDS object API, as it would be quite unnatural to use in Rust as such.
+//! However, we aim for functional compatibility, while at the same time using
+//! Rust techniques and conventions.
 //!
 //! Additionally, there is a [ROS2](https://index.ros.org/doc/ros2/) interface, that is simpler to use than DDS
 //! when communicating to ROS2 components.
-//!
 
-#![warn(clippy::all)]
+#![deny(clippy::all)]
 #![allow(
   clippy::option_map_unit_fn,
-  clippy::wrong_self_convention,
-  clippy::single_match,
+  // option_map_unit_fn suggests changing option.map( ) with () return value to if let -construct,
+  // but that may break code flow.
   dead_code
 )]
 
