@@ -3,7 +3,7 @@ use std::{
   net::{IpAddr, Ipv4Addr, SocketAddr},
 };
 
-use mio::{net::UdpSocket, Token};
+use mio::net::UdpSocket;
 use log::{debug, error, info, trace};
 use socket2::{Domain, Protocol, SockAddr, Socket, Type};
 use bytes::{Bytes, BytesMut};
@@ -19,7 +19,6 @@ const MESSAGE_BUFFER_ALLOCATION_CHUNK: usize = 256 * 1024; // must be >= MAX_MES
 #[derive(Debug)]
 pub struct UDPListener {
   socket: UdpSocket,
-  token: Token,
   receive_buffer: BytesMut,
   multicast_group: Option<Ipv4Addr>,
 }
@@ -37,11 +36,7 @@ impl Drop for UDPListener {
   }
 }
 
-// TODO: Remove panics from this function. Convert return value to Result.
 impl UDPListener {
-  // TODO: Why is is this function even necessary? Doesn't try_bind() do just the
-  // same?
-
   fn new_listening_socket(host: &str, port: u16, reuse_addr: bool) -> io::Result<UdpSocket> {
     let raw_socket = Socket::new(Domain::IPV4, Type::DGRAM, Some(Protocol::UDP))?;
 
@@ -87,19 +82,23 @@ impl UDPListener {
     Ok(mio_socket)
   }
 
-  pub fn new_unicast(token: Token, host: &str, port: u16) -> io::Result<UDPListener> {
+  // Note that this typically does not give the local IP address, but
+  // "0.0.0.0", which means we are listening to any address.
+  pub fn to_socketaddr(&self) -> io::Result<SocketAddr> {
+    self.socket.local_addr()
+  }
+
+  pub fn new_unicast(host: &str, port: u16) -> io::Result<UDPListener> {
     let mio_socket = Self::new_listening_socket(host, port, false)?;
 
     Ok(UDPListener {
       socket: mio_socket,
-      token,
       receive_buffer: BytesMut::with_capacity(MESSAGE_BUFFER_ALLOCATION_CHUNK),
       multicast_group: None,
     })
   }
 
   pub fn new_multicast(
-    token: Token,
     host: &str,
     port: u16,
     multicast_group: Ipv4Addr,
@@ -124,16 +123,11 @@ impl UDPListener {
 
     Ok(UDPListener {
       socket: mio_socket,
-      token,
       receive_buffer: BytesMut::with_capacity(MESSAGE_BUFFER_ALLOCATION_CHUNK),
       multicast_group: Some(multicast_group),
     })
   }
 
-  pub fn get_token(&self) -> Token {
-    self.token
-  }
-
   pub fn mio_socket(&mut self) -> &mut UdpSocket {
     &mut self.socket
   }
@@ -245,7 +239,7 @@ mod tests {
 
   #[test]
   fn udpl_single_address() {
-    let listener = UDPListener::new_unicast(Token(0), "127.0.0.1", 10001).unwrap();
+    let listener = UDPListener::new_unicast("127.0.0.1", 10001).unwrap();
     let sender = UDPSender::new_with_random_port().expect("failed to create UDPSender");
 
     let data: Vec<u8> = vec![0, 1, 2, 3, 4];
@@ -262,8 +256,7 @@ mod tests {
   #[test]
   fn udpl_multicast_address() {
     let listener =
-      UDPListener::new_multicast(Token(0), "0.0.0.0", 10002, Ipv4Addr::new(239, 255, 0, 1))
-        .unwrap();
+      UDPListener::new_multicast("0.0.0.0", 10002, Ipv4Addr::new(239, 255, 0, 1)).unwrap();
     let sender = UDPSender::new_with_random_port().unwrap();
 
     //setsockopt(sender.socket.as_raw_fd(), IpMulticastLoop, &true)
