@@ -13,18 +13,7 @@ pub fn get_local_multicast_locators(port: u16) -> Vec<Locator> {
   vec![Locator::from(saddr)]
 }
 
-pub fn get_local_multicast_ip_addrs() -> io::Result<Vec<IpAddr>> {
-  let ifs = if_addrs::get_if_addrs()?;
-  Ok(
-    ifs
-      .iter()
-      .filter(|ifaddr| (!ifaddr.is_loopback()))
-      .map(|ifaddr| ifaddr.ip())
-      .collect(),
-  )
-}
-
-pub fn get_local_unicast_socket_address(port: u16) -> Vec<Locator> {
+pub fn get_local_unicast_locators(port: u16) -> Vec<Locator> {
   match if_addrs::get_if_addrs() {
     Ok(ifaces) => ifaces
       .iter()
@@ -40,3 +29,20 @@ pub fn get_local_unicast_socket_address(port: u16) -> Vec<Locator> {
     }
   }
 }
+
+// Enumerates local ip interfaces that we use for multicasting.
+// This is used to set up senders and listeners.
+//
+// TODO: Check that the interface actually has multicast enabled.
+// Now we just skip loopback.
+// Could use e.g. "interfaces" crate to do this.
+pub fn get_local_multicast_ip_addrs() -> io::Result<Vec<IpAddr>> {
+  let ifs = if_addrs::get_if_addrs()?;
+  Ok(
+    ifs
+      .iter()
+      .filter(|ifaddr| !ifaddr.is_loopback())
+      .map(|ifaddr| ifaddr.ip())
+      .collect(),
+  )
+}
